//  File:  AutoBoxing.java  -  Demonstrate automatic "boxing" and "unboxing"
//
//  Read http://java.sun.com/j2se/1.5.0/docs/guide/language/index.html for more details
//  And, see the bottom of this file for more references...

import java.util.*;

public class AutoBoxing {

    public static void simple() {
        int nInt = 42;
        Integer nInteger;

        nInteger = nInt;                                     // auto-box
        System.out.println("nInteger = " + nInteger);        // prints 42

        nInteger = new Integer(nInteger.intValue() + 3);
        nInt = nInteger;                                     // auto-unbox
        System.out.println("nInt     = " + nInt);            // prints 45
    }

    public static void frequency() {
        String[] sData = { "if", "it", "is", "to", "be", "it", "is", 
                           "up", "to", "me", "to", "do", "the", "watusi" };
        Map<String, Integer> map = new TreeMap<String, Integer>();
        for (String sWord : sData) {
            Integer freq = map.get(sWord);                   // auto-box
            map.put(sWord, (freq == null ? 1 : freq + 1));   // both
        }
        System.out.println(map);
    }

    public static void main(String[] args) {
        System.out.println("Demonstrate automatic boxing and unboxing\n");
        simple();
        System.out.println();
        frequency();
        System.out.println();
    }

}

/* ===== Output =====

Demonstrate automatic boxing and unboxing

nInteger = 42
nInt     = 45

{be=1, do=1, if=1, is=2, it=2, me=1, the=1, to=3, up=1, watusi=1}

===== End Output ===== */

/* .....

Tutorials on Autoboxing
=======================

Autoboxing
http://java.sun.com/j2se/1.5.0/docs/guide/language/autoboxing.html

Boxing Conversion in J2SE 5.0
http://today.java.net/pub/a/today/2005/03/24/autoboxing.html

Autoboxing Yourself in JDK 1.5
http://cretesoft.com/archive/newsletter.do?issue=090

Autoboxing/Unboxing of Wrappers
http://www.particle.kth.se/~lindsey/JavaCourse/Book/Part1/Java/Chapter03/autobox.html

Autoboxing support for the Javatm Programming Language
http://www.jcp.org/aboutJava/communityprocess/jsr/tiger/autoboxing.html


There are tons of examples out there accessible via Google
..... */
